/*
|--------------------------------------------------------------------------
| UItoTop jQuery Plugin 1.2
| http://www.mattvarone.com/web-design/uitotop-jquery-plugin/
|--------------------------------------------------------------------------
*/

#toTop {
	display:none;
	text-decoration:none;
	position:fixed;
	bottom:10px;
	right:10px;
	overflow:hidden;
	width:22px;
	border:1px solid Orange;
    background-color: Orange;
    color:#000;
    text-align: center;
    -webkit-border-radius: 5px;
    -moz-border-radius: 5px;
    border-radius: 5px;
}

#toTopHover {
	display:block;
	overflow:hidden;
	float:left;
	-moz-opacity: 0;
}

#toTop:active, #toTop:focus {
	outline:none;
}
